@@ -284,7 +284,7 @@ unsigned TablePosStart;
     "extern const char *SimpleTable[];\n"
    "\n"
     "/*This function expands an extended WP character into LaTEX sequence*/\n"
-    "const char *Ext_chr_str(WORD wchar_code, TconvertedPass1 *cq, CpTranslator *ConvertCP)\n"
+    "const char *Ext_chr_str(WORD wchar_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP)\n"
     "{\n"
     "#ifdef DEBUG\n"
     "  fprintf(cq->log,\"\\n#Ext_chr_str(0x%%X) \",wchar_code);fflush(cq->log);\n"
@@ -480,7 +480,7 @@ codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1255, cp1276, cpkam,
 	 mtef2,
          MAC_ROMAN;
 codepage cphtml;
-codepage symbol;
+codepage symbol, Wingdings;
 Translator trn;
 doublelist llHTML;
 string FileName;
@@ -543,6 +543,7 @@ string FileName;
 
  LoadCodePage("mtef2",mtef2,0);
  LoadCodePage("symbol",symbol,0);
+ LoadCodePage("Wingdings",Wingdings,0);
  LoadCodePage("mac_roma",MAC_ROMAN,0);
  if(MAC_ROMAN.name){free(MAC_ROMAN.name);MAC_ROMAN.name=strdup("MacRoman");}
 
@@ -715,11 +716,14 @@ WriteTranslator(cp1250,cpkam,trn,F);
  }
 
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- CreateTranslator(trn,symbol,internal);
- WriteTranslator(symbol,internal,trn,F);
+ CreateTranslator(trn, symbol, internal);
+ WriteTranslator(symbol, internal, trn, F);
 
- CreateTranslator(trn,mtef2,internal);
- WriteTranslator(mtef2,internal,trn,F);
+ CreateTranslator(trn, Wingdings, internal);
+ WriteTranslator(Wingdings, internal, trn, F);
+
+ CreateTranslator(trn, mtef2, internal);
+ WriteTranslator(mtef2, internal, trn, F);
  if(FcloseEpilog(F,FileName(),"mtef.trn")) return -1;
 
 
