@@ -80,6 +80,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "RIGHT", "5", 0 },
    { "HAT", "{5{0}}", 0 },
    { "DOT", "{5{0}}", 0 },
+   { "MATRIX", "\\begin{array}{7}1\\end{array}", 0 },
 
 /* 11 char words */
    { "SMALLCOPROD", "\\coprod", 0 },	/* bad translation */
@@ -134,7 +135,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "omikron", "o", 0 },			/* very bad translation */
    { "OMIKRON", "O", 0 },			/* very bad translation */
    { "MASSERT", "\\dashv", 0 },
-   { "MATFORM", "", 0 },			/* no translation kwown */
+   { "MATFORM", "\\iffalse 1 \\fi ", 0 },	/* {MATRIX{MATFORM{ALIGNC&ALIGNC&ALIGNC&ALIGNC}{t_1(s)}&{0}&{. . . . . . */
    { "MSANGLE", "\\measuredangle", AMSSYMB },
    { "NASYMEQ", "\\not\\asymp", 0 },
    { "PARTIAL", "5", 0 },
@@ -144,9 +145,9 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "upsilon", "\\upsilon", 0 },
    { "UPSILON", "\\Upsilon", 0 },
 /* 6 char words */
-   { "ALIGNC", "", 0 },			/* no translation known */
-   { "ALIGNL", "", 0 },
-   { "ALINGR", "", 0 },
+   { "ALIGNC", "", 0 },				/* Valid only in MATRIX header MATFORM */
+   { "ALIGNL", "", 0 },				/* Valid only in MATRIX header MATFORM */
+   { "ALINGR", "", 0 },				/* Valid only in MATRIX header MATFORM */
    { "APPROX", "5", 0 },
    { "arccos", "5", 0 },
    { "arcsin", "5", 0 },
@@ -166,8 +167,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "LBRACE", "\\{", 0 },
    { "LFLOOR", "5", 0 },
    { "liminf", "5", 0 },
-   { "limsup", "5", 0 },
-   { "MATRIX", "\\begin{array}{7}1\\end{array}", 0 },
+   { "limsup", "5", 0 },   
    { "MODELS", "5", 0 },
    { "NEQUIV", "\\not\\equiv", 0 },
    { "OMINUS", "5", 0 },
@@ -339,8 +339,8 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "XI", "\\Xi", 0 },
    { "\\'", "'", 0 },			/* Bad conversion - symbol should be like ^{|} */
 /* words with 1 char */
-   { "^", "^{1}", 0 },
-   { "_", "_{1}", 0 },
+   { "^", "^{9}", 0 },
+   { "_", "_{9}", 0 },
    {"#"," \\\\ ", 0 },			/* New line for multiline formula */
    { "'", "{0'}", 0 },
    { "%", "\\%", }
@@ -726,6 +726,7 @@ bool FirstCipher = false;
 
  InternalArg = arg; //Check whether arg contains any non-terminal symbol that need to be expanded
  InternalArg.ToUpper();
+
  for(i=0; i<nFmlTransWords; i++)
   {
   if(arg==FmlTransTable[i].szWP || InternalArg==FmlTransTable[i].szWP)
@@ -762,9 +763,9 @@ return(LastC);
 /** This procedure removes argument from the beginning of the string with x^y_z stuff.
  * @param[in,out] str	Formula data that shoud be split.
  * @param[out]	  arg	Argument extracred from formula. */
-static bool RemoveAdvanced1stArg(string & str, string & arg)
+static bool RemoveAdvanced1stArg(string & str, string & arg, char BlockChar=0)
 {
-int i, ZeroPass;
+int Level, ZeroPass;
 char c;
 char LastC, LastSupSub;
 string InternalArg;
@@ -775,18 +776,20 @@ string InternalArg;
     str=copy(str,1,length(str)-1);
 
   LastSupSub = LastC = '\0';
-  ZeroPass = i = 0;
+  ZeroPass = Level = 0;
   while(!str.isEmpty())
      {
-     c = str[0];
-     if(i<=0 && !isspace(c) && !LastSupSub)
-       if(!arg.isEmpty())		//argument is not empty
-	{
-	if( (isspace(LastC) ||
+     c = str[0];     
+     if(Level<=0 && !isspace(c))
+       {
+       if(c==BlockChar) break;
+       if(!LastSupSub && !arg.isEmpty())	//argument is not empty
+	 {
+	 if((isspace(LastC) ||
 	      LastC=='}' || LastC==']' || LastC==')' || LastC=='"' || LastC=='\'') &&
 	    (!isspace(c) && c!='_' && c!='^') ) break;
 
-	if(c=='\\' ||                    //These characters break WP argument
+	 if(c=='\\' ||                    //These characters break WP argument
 	   c==',' || c=='?' || c=='!' ||
 	   c=='(' || c==')' || c=='[' || c==']' ||
 	   c=='*' || c == '/' || c=='+' || c == '-' ||
@@ -799,7 +802,8 @@ string InternalArg;
                }
              break;
              }
-	}
+	 }
+       }
 
     for(int j=0; j<sizeof(FixTable)/sizeof(FixTable[0]); j++)
       if(!strncmp(str(),FixTable[j].lo,FixTable[j].Len) || !strncmp(str(),FixTable[j].up,FixTable[j].Len))
@@ -807,7 +811,7 @@ string InternalArg;
         if((isspace(str[FixTable[j].Len])||str[FixTable[j].Len]=='{') && (LastC=='\\' || isspace(LastC)))
 	  {
 	  c = str[FixTable[j].Len];
-	  i += FixTable[j].inc;
+	  Level += FixTable[j].inc;
 	  LastSupSub = 2;		//protect next char against break
 	  str = copy(str, FixTable[j].Len, length(str)-FixTable[j].Len);
 	  arg += FixTable[j].lo;
@@ -823,18 +827,21 @@ string InternalArg;
         {
         if (c == '{')
 	     {
-	     i++;
+	     Level++;
 	     }
         if (c == '}')
 	     {
-	     i--;
-             if(i==0) ZeroPass++;
+	     Level--;
+             if(Level==0) ZeroPass++;
 	     }
         }
 
     arg += c;
-    if(!isspace(c)) LastSupSub=0;
-    if(c == '_' || c == '^') LastSupSub=1;
+    if(!isspace(c))
+    {
+      LastSupSub = 0;
+      if(c=='_' || c=='^') LastSupSub=1;
+    }
 CONTINUE:
     LastC = c;
     }
@@ -849,22 +856,22 @@ if(arg.isEmpty()) return(0);
 
 InternalArg=arg; //Check whether arg contains any non-terminal symbol that need to be expanded
 InternalArg.ToUpper();
-for (i = 0; i < nFmlTransWords; i++)
+for(int j=0; j<nFmlTransWords; j++)
   {
-  if(arg==FmlTransTable[i].szWP || InternalArg==FmlTransTable[i].szWP)
+  if(arg==FmlTransTable[j].szWP || InternalArg==FmlTransTable[j].szWP)
     {
-    if(strstr(FmlTransTable[i].szTeX,"1")!=NULL)
+    if(strstr(FmlTransTable[j].szTeX,"1")!=NULL)
 	{
 	if(Remove1stArg(str,InternalArg)=='}')
-	   arg=arg+"{"+InternalArg+"}";
+	   arg = arg+"{"+InternalArg+"}";
 	else
 	   arg+=" "+InternalArg;
-	if(strstr(FmlTransTable[i].szTeX,"2")!=NULL)
+	if(strstr(FmlTransTable[j].szTeX,"2")!=NULL)
 	   {
 	   if(Remove1stArg(str,InternalArg)=='}')
-	     arg=arg+"{"+InternalArg+"}";
+	     arg = arg + "{"+InternalArg + "}";
 	   else
-	     arg+=" "+InternalArg;
+	     arg += " " + InternalArg;
 	   }
 	}
     break;
@@ -1105,38 +1112,70 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 		  strB+=arg[1];
 		  break;
 
-	case '2': if (p == 0)  p = length(strB);
+	case '2': if(p == 0)  p = length(strB);
 		  strB+=arg[2];
 		  break;
 
-	case '3': if (p == 0)  p = length(strB);
+	case '3': if(p == 0)  p = length(strB);
 		  strB+=arg[3];
 		  break;
 
-	case '4': if (p == 0)  p = length(strB);
+	case '4': if(p == 0)  p = length(strB);
 		  strB+=arg[4];
 		  break;
 
-	case '5': strB+="\\"+ToLower(symbol);
+	case '5': strB += "\\" + ToLower(symbol);
 		  break;
 
-	case '6': strB+="\\"+string(symbol);
+	case '6': strB += "\\" + string(symbol);
 		  break;
 
         case '7': a = 0;
                   a2 = 0;
-		  for (j = 0; j < length(arg[1]); j++)
-                         {
-			 if (arg[1][j] == '&') a2++;
-			 if (arg[1][j] == '#')
-			     {
-			     if (a2 > a) a = a2;
-                             a2 = 0;
-                             }
-                         }
-                   if (a2 > a) 	a = a2;
+		  j = 0;
+		  while(j<length(arg[1]) && isspace(arg[1][j])) j++;
+		  if(!strncmp("MATFORM",arg[1]()+j,7))			// The matrix contains a header.
+		      {
+		      j += 7;
+		      while(j<length(arg[1]) && isspace(arg[1][j])) j++;
+		      string Header;
+		      string Str1(arg[1]()+j);
+		      Remove1stArg(Str1,Header);
+		      if(!Header.isEmpty())
+			{
+			char DefaultAllign = 'c';
+			for(j=0; j<length(Header); j++)
+			  {
+			  if(Header[j]=='&')
+			    {
+			    strB += DefaultAllign;
+			    DefaultAllign = 'c';
+			    continue;
+			    }
+			  if(Header[j]=='A')
+			    {
+			    if(!strncmp(Header()+j,"ALIGNC",6)) {DefaultAllign='c';continue;}
+			    if(!strncmp(Header()+j,"ALIGNL",6)) {DefaultAllign='l';continue;}
+		            if(!strncmp(Header()+j,"ALIGNR",6)) {DefaultAllign='r';continue;}
+			    }
+			  }
+			strB += DefaultAllign;
+		        break;
+                        }
+		      }
+		  while(j < length(arg[1]))
+                      {
+		      if(arg[1][j] == '&') a2++;
+			if(arg[1][j] == '#')
+			  {
+			  if (a2 > a) a = a2;
+                          a2 = 0;
+                          }
+			j++;
+                      }
+                   if(a2 > a) 	a = a2;
 
-		   for (j = 0; j <= a; j++)  strB+='c';
+		   for(j = 0; j <= a; j++)  strB+='c';
                    break;
 
         case '9': if (p == 0) p = length(strB);
@@ -1461,8 +1500,8 @@ BYTE styles;
 
   if(StrBeg.isEmpty()) return(false);  /*equation is empty-nothing to do*/
 
-  StrBeg = replacesubstring(StrBeg,"\1}","\\}");              /*fix \} in WP -> \1 -> "\}"*/
-  StrBeg = replacesubstring(StrBeg,"\1{","\\{");              /*fix \} in WP -> \1 -> "\}"*/
+  StrBeg = replacesubstring(StrBeg,"\1}","\\}");	// fix \} in WP -> \1 -> "\}"
+  StrBeg = replacesubstring(StrBeg,"\1{","\\{");	// fix \} in WP -> \1 -> "\}"  
   bool error = FixFormula(cq,StrBeg,i,j);
 
 	//Here starts an equation conversion phase
@@ -1484,7 +1523,8 @@ BYTE styles;
 		i+=11;   //  > strlen(" \\nonumber # ")-1
 		}
 	}
-// if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",StrBeg.ch);
+
+// if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",StrBeg()); ///<<<<<
 
   StrEnd.erase();
   for(i=0; i<nFmlTransWords; i++)
@@ -1494,9 +1534,10 @@ BYTE styles;
 
       while(RemoveSymbol(StrBeg, StrEnd, FmlTransTable[i].szWP))
 	   {
+	   //if(cq->log!=NULL) fprintf(cq->log,"\n%s |||| %s\n",StrBeg(),StrEnd()); ///<<<<<
 	   if(FmlTransTable[i].styles != 0) /* check additional styles */
 		{
-		styles=FmlTransTable[i].styles;
+		styles = FmlTransTable[i].styles;
 		if((styles & WP2LATEX) != 0) 
 		  {
 		  WP2LaTeXsty += sty_between;
@@ -1551,14 +1592,20 @@ BYTE styles;
 	       {
 	       RemoveLastArg(StrBeg,arg[0]);
 	       }
+
 	   if(strstr(FmlTransTable[i].szTeX, "9") != NULL)
 	       {
-	       RemoveAdvanced1stArg(StrEnd, arg[1]);
-	       } else
-	   if(strstr(FmlTransTable[i].szTeX, "1") != NULL)
+	       if(FmlTransTable[i].szWP[0]=='_') 
+			RemoveAdvanced1stArg(StrEnd, arg[1], '^');	// Stop on oposite accent
+	       else if(FmlTransTable[i].szWP[0]=='^') 
+			RemoveAdvanced1stArg(StrEnd, arg[1], '_');	// Stop on oposite accent
+	       else RemoveAdvanced1stArg(StrEnd, arg[1]);		// Grab both subscript and also superscript.
+	       } 
+           else if(strstr(FmlTransTable[i].szTeX, "1") != NULL)
 	       {
 	       Remove1stArg(StrEnd,arg[1]);
 	       }
+
 	   if(strstr(FmlTransTable[i].szTeX, "2") != NULL)
 	       {
 	       Remove1stArg(StrEnd,arg[2]);
@@ -1576,6 +1623,8 @@ BYTE styles;
   StrEnd = StrBeg + StrEnd; /* Fix double superscript/subscript */  
   StrBeg.erase();
 
+  //if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",StrEnd()); ///<<<<<
+
 	// Check braces \left and \right
   if(CheckFormulaLeftRight(StrEnd(),i,j))
   {
@@ -1782,6 +1831,8 @@ string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set)
   StrEnd = StrBeg + StrEnd;
   StrBeg.erase();
 
+  StrEnd = replacesubstring(StrEnd,"\\\"","\\ddot");	// Fix umlaut, \" cannot be placed in math mode.
+
 	// https://www.maths.tcd.ie/~dwilkins/LaTeXPrimer/MathAccents.html
   StrEnd = replacesubstring(StrEnd,"\\'","\2acute ");
   StrEnd = replacesubstring(StrEnd,"\\=","\2bar ");  
