@@ -366,7 +366,6 @@ string str;
 return temp_string(str);
 }
 
-
 void VectorEllipse::Transform(const AbstractTransformXY &Tx)
 {
   Tx.ApplyTransform(LeftRect, BottomRect);
@@ -482,6 +481,15 @@ void VectorRectangle::Transform(const AbstractTransformXY &Tx)
 }
 
 
+#ifdef _DEBUG
+void VectorRectangle::Dump2File(FILE *F) const
+{
+  fprintf(F,"VectorRectangle{Left=%2.2f; Right=%2.2f; Bottom=%2.2f; Top=%2.2f}\n", 
+	  LeftRect, RightRect, BottomRect, TopRect);
+}
+#endif
+
+
 /////////////////////////////////////////////////////////////
 
 VectorRectangleArc::VectorRectangleArc(float iniBottomRect, float iniTopRect, 
@@ -495,8 +503,14 @@ VectorRectangleArc::VectorRectangleArc(float iniBottomRect, float iniTopRect,
 
 void VectorRectangleArc::Transform(const AbstractTransformXY &Tx)
 {
-  VectorRectangle::Transform(Tx);
-  Tx.ApplyTransform(Hradius, Vradius);
+float Hr1,Hr2, Vr1,Vr2;
+  Hr1 = LeftRect;	Hr2 = LeftRect + Hradius;
+  Vr1 = BottomRect;	Vr2 = BottomRect + Vradius;
+  VectorRectangle::Transform(Tx);  
+  Tx.ApplyTransform(Hr1, Vr1);
+  Tx.ApplyTransform(Hr2, Vr2);
+  Hradius = Hr2 - Hr1;
+  Vradius = Vr2 - Vr1;
   if(Hradius<0) Hradius=-Hradius;
   if(Vradius<0) Vradius=-Vradius;
 }
@@ -504,7 +518,6 @@ void VectorRectangleArc::Transform(const AbstractTransformXY &Tx)
 
 temp_string VectorRectangleArc::Export2EPS(PS_State *PSS) const
 {
-float Ty = 1;
 bool ContextSaved = false;
 
   if(fabs(Hradius)<1e-5 || fabs(Vradius)<1e-5 || Tx!=NULL)
@@ -524,30 +537,42 @@ bool ContextSaved = false;
   
   float Y_ll = BottomRect;
   float Y_ur = TopRect;
+
   if(fabs(Hradius-Vradius) > 1e-5)
   {	//Horizontal and Vertical radiuses are different - scale canvas
-    Ty = Vradius/Hradius;
+    const float Ty = Vradius/Hradius;
     if(!ContextSaved) PSData+="\ngsave";
     PSData.cat_printf("\n0 %2.2f translate\n1 %2.3f scale", Y_ll, 1.0/Ty);
     Y_ur -= Y_ll;
     Y_ll = 0;
+    Y_ur *= Ty;
     ContextSaved = true;
  }
 
  PSData += "\nnewpath";
- PSData.cat_printf("\n%2.2f %2.2f moveto", LeftRect+Hradius, Ty*Y_ll);
- PSData.cat_printf("\n%2.2f %2.2f %2.2f 270 0 arc", LeftRect-Hradius, Ty*Y_ll+Hradius , Hradius);
- PSData.cat_printf("\n%2.2f %2.2f %2.2f 0 90 arc", LeftRect-Hradius, Ty*Y_ur-Hradius, Hradius);
- PSData.cat_printf("\n%2.2f %2.2f %2.2f 90 180 arc", RightRect+Hradius, Ty*Y_ur-Hradius, Hradius);
- PSData.cat_printf("\n%2.2f %2.2f %2.2f 180 270 arc", RightRect+Hradius, Ty*Y_ll+Hradius, Hradius);
+ PSData.cat_printf("\n%2.2f %2.2f moveto", RightRect-Hradius, Y_ll);
+ PSData.cat_printf("\n%2.2f %2.2f %2.2f 270 0 arc", RightRect-Hradius, Y_ll+Hradius, Hradius);
+ PSData.cat_printf("\n%2.2f %2.2f %2.2f 0 90 arc", RightRect-Hradius, Y_ur-Hradius, Hradius);
+ PSData.cat_printf("\n%2.2f %2.2f %2.2f 90 180 arc", LeftRect+Hradius, Y_ur-Hradius, Hradius);
+ PSData.cat_printf("\n%2.2f %2.2f %2.2f 180 270 arc", LeftRect+Hradius, Y_ll+Hradius, Hradius);
 
  PSData+="\nclosepath";
- FillObjectPS(RightRect, LeftRect, Ty*Y_ll, Ty*Y_ur,PSData,PSS);
+ FillObjectPS(RightRect, LeftRect, Y_ll, Y_ur,PSData,PSS);
  if(ContextSaved) PSData+="\ngrestore";
  return temp_string(PSData);
 }
 
 
+#ifdef _DEBUG
+void VectorRectangleArc::Dump2File(FILE *F) const
+{
+  fprintf(F,"VectorRectangleArc{Left=%2.2f; Right=%2.2f; Bottom=%2.2f; Top=%2.2f; Hradius=%2.2f; Vradius=%2.2f}\n", 
+	  LeftRect, RightRect, BottomRect, TopRect, Hradius, Vradius);
+}
+#endif
+
+
+
 /////////////////////////////////////////////////////////////
 
 
@@ -622,6 +647,20 @@ string str;
 }
 
 
+#ifdef _DEBUG
+void VectorPolygon::Dump2File(FILE *F) const
+{
+const float *pEnd = Points + 2*CountPoints;
+  fputs("VectorPolygon{",F);
+  for(float *p=Points; p<pEnd; p+=2)
+  {
+    fprintf(F,"[%2.2f;%2.2f]", p[0], p[1]);
+  }
+  fputs("}\n",F);
+}
+#endif
+
+
 void VectorPolygon::Transform(const AbstractTransformXY &Tx)
 {
   if(Points==NULL || CountPoints<=0) return;
@@ -973,6 +1012,20 @@ string str;
 }
 
 
+#ifdef _DEBUG
+void VectorLine::Dump2File(FILE *F) const
+{
+const float *pEnd = Points + 2*CountPoints;
+  fputs("VectorLine{",F);
+  for(float *p=Points; p<pEnd; p+=2)
+  {
+    fprintf(F,"[%2.2f;%2.2f]", p[0], p[1]);
+  }
+  fputs("}\n",F);
+}
+#endif
+
+
 void VectorLine::Transform(const AbstractTransformXY &Tx)
 {
   if(Points==NULL || CountPoints<=0) return;
@@ -1037,6 +1090,20 @@ VectorObject *IterObject = FirstObject;
 }
 
 
+#ifdef _DEBUG
+void VectorList::Dump2File(FILE *F) const
+{
+VectorObject *IterObject = FirstObject;
+
+  while(IterObject!=NULL)
+  {
+    IterObject->Dump2File(F);
+    IterObject = IterObject->NextObject;
+  }
+}
+#endif
+
+
 void VectorList::FeaturesEPS(unsigned & Feature) const
 {
 VectorObject *IterObject = FirstObject;
@@ -1349,6 +1416,23 @@ return temp_string(str);
 }
 
 
+#ifdef _DEBUG
+void TextContainer::Dump2File(FILE *F) const
+{
+  fputs("TextContainer{",F);  
+  for(int i=0; i<TextObjects; i++)
+    {
+      if(Text[i]!=NULL)
+      {
+      fprintf(F,"FontSz=%f;", Text[i]->size);
+      fprintf(F,"%s\"%s\"", (i==0)?"":",", Text[i]->contents);
+      }
+    }
+  fputs("}\n",F);
+}
+#endif
+
+
 void TextContainer::Transform(const AbstractTransformXY &Tx)
 {
   RotCenterX += PosX;
