@@ -32,7 +32,7 @@ typedef struct
 	float FontSize, FontSizeW;	///< Size of font in [mm].
 	WORD FontWeight;
 	SWORD FontOrientation10;	///< Text rotation request.
-        CpTranslator *ConvertCpg;
+        const CpTranslator *ConvertCpg;
         
 	char FontItallic;
 	char dirty;
@@ -137,7 +137,7 @@ public:
   vecFont(const PS_State &PSS);
   virtual void prepExport(PS_State *PSS) const;
 
-  CpTranslator *ConvertCpg;
+  const CpTranslator *ConvertCpg;
   RGB_Record TextColor;
   float FontSize, FontSizeW;
   WORD Weight;
@@ -190,6 +190,9 @@ public:
   virtual void Transform(const AbstractTransformXY &Tx) {}
   virtual void FeaturesEPS(unsigned & Feature) const {return;}
   virtual unsigned isInside(float xp, float yp) const {return 0;}
+#ifdef _DEBUG
+  virtual void Dump2File(FILE *F) const {}
+#endif
 
   virtual ~VectorObject() {NextObject=NULL;UpperCont=NULL;}
   VectorObject() {NextObject=NULL;UpperCont=NULL;}
@@ -219,6 +222,9 @@ public:
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   void Export2EPS(FILE *F, PS_State *PSS=NULL) const;
   virtual void FeaturesEPS(unsigned & Feature) const;
+#ifdef _DEBUG
+  virtual void Dump2File(FILE *F) const;
+#endif
   VectorList(void);
   virtual ~VectorList();
 
@@ -258,6 +264,9 @@ public:
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
+#ifdef _DEBUG
+  virtual void Dump2File(FILE *F) const;
+#endif
 
   int CountPoints;
   float *Points;  	///< x, y coordinate list of the line.
@@ -289,6 +298,9 @@ public:
   virtual unsigned isInside(float xp, float yp) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
   virtual void FeaturesEPS(unsigned & Feature) const  {vecBrush::FeaturesEPS(Feature);}
+#ifdef _DEBUG
+  virtual void Dump2File(FILE *F) const;
+#endif
 
   //unsigned isInsideX(float xp, float yp) const;
   //unsigned isInsideY(float xp, float yp) const;
@@ -310,6 +322,9 @@ public:
   virtual void Transform(const AbstractTransformXY &Tx);
   virtual unsigned isInside(float xp, float yp) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
+#ifdef _DEBUG
+  void Dump2File(FILE *F) const;
+#endif
 
   AbstractTransformXY *Tx;
   float	BottomRect, TopRect, RightRect, LeftRect;
@@ -324,6 +339,9 @@ public:
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
+#ifdef _DEBUG
+  void Dump2File(FILE *F) const;
+#endif
 
   float	Hradius, Vradius;
 };
@@ -356,7 +374,10 @@ public:
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
   virtual void FeaturesEPS(unsigned & Feature) const;
-  
+#ifdef _DEBUG
+  void Dump2File(FILE *F) const;
+#endif
+
   void AddText(temp_string contents, const PS_State &PSS);
   void AddText(temp_string contents, const char *font, const PS_State &PSS);
 
