@@ -2008,19 +2008,26 @@ void TconvertedPass1_WP5::ProcessKey(void)
 
 	default:if(by>=0x01 && by<=0x7f)
 		     {
-		     if(RequiredFont==FONT_HEBREW)
+		     if(NativeCpg != NULL)
 		       {
-		       if(by=='.')
-                          {CharacterStr(this,"\\textrm{.}");break;}
-                       if(by==',')
-                          {CharacterStr(this,"\\textrm{,}");break;}
-		       if(by==':')
-                          {CharacterStr(this,"\\textrm{:}");break;}
-                       if(by==';')
-                          {CharacterStr(this,"\\textrm{;}");break;}
+	               CharacterStr(this,Ext_chr_str(by,this,NativeCpg));
+		       }
+		     else
+                       {
+		       if(RequiredFont==FONT_HEBREW)
+		         {
+		         if(by=='.')
+                            {CharacterStr(this,"\\textrm{.}");break;}
+                         if(by==',')
+                            {CharacterStr(this,"\\textrm{,}");break;}
+		         if(by==':')
+                            {CharacterStr(this,"\\textrm{:}");break;}
+                         if(by==';')
+                            {CharacterStr(this,"\\textrm{;}");break;}
+                         }
+		       RequiredFont = FONT_NORMAL;
+     		       CharacterStr(this,Ext_chr_str(by,this,ConvertCpg));   /* Normal_char */
                        }
-		     RequiredFont = FONT_NORMAL;
-     		     CharacterStr(this,Ext_chr_str(by,this,ConvertCpg));   /* Normal_char */
 		     }
 		break;
 	}
