@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.102"
-#define VersionDate	"2 Dec 2021"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.103"
+#define VersionDate	"2 Jan 2022"  /* day (space) month (space) full year */
 
 #ifndef false
  #define  false          0
@@ -243,11 +243,12 @@ public:
   char ObjType[48];
 
   FILE *wpd, *table, *strip, *log, *err;
-  CpTranslator *ConvertCpg;
+  const CpTranslator *ConvertCpg;
+  const CpTranslator *NativeCpg;
 
   virtual int Convert_first_pass(void)=0;
   virtual int Dispatch(int Func, const void *arg=NULL) {return(-1);}
-  void InitMe(FILE *FileIn, FILE *Table, FILE *StripOut, FILE *LogFile,FILE *ErrorFile);
+  void InitMe(FILE *FileIn, FILE *Table, FILE *StripOut, FILE *LogFile, FILE *ErrorFile);
 };
 
 void ReportNoMemory(TconvertedPass1 *cq=NULL);
@@ -291,7 +292,7 @@ struct RGBQuad
 #define KOI8R		8
 #define UTF8		16384
 
-const char *Ext_chr_str(WORD char_code, TconvertedPass1 *cq, CpTranslator *ConvertCP=NULL);
+const char *Ext_chr_str(WORD char_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP=NULL);
 
 typedef enum {aExtraLarge=0, aVeryLarge1=1, aLarge=2, aSmall=3, aFine=4,
 	      aSupscript=5, aSubscript=6, aOutline=7, aItalic=8, aShadow=9,
